﻿////////////////////////////////////////////////////////
//
// $DDCDriver.Name: FOS_20160929_Version_1
// $DDCDriver.Desc: FÖS mall 20160929 - version 1
// 
// Denna driver är för FÖS enligt 'Mall IO-lista 20160929.xlsx' från Janne Lolaks
//
// Dokumentet är sparat i UTF-8 för att vara compliant med JavaScript (i annat fall orsakar svenska tecken ett parsingfel)
// 
// --------------------------------------------------------------------------------------------------------------------------------
// Date     / Vers   / Sign / Comment
// --------------------------------------------------------------------------------------------------------------------------------
// 16.10.05 / 01.00  /  TR  / Main
//
//
////////////////////////////////////////////////////////

function ReadDaysFromDDC() {

  var iDayIndex;
  var iStartStopIndex;
  var sTagName;

  tsc = new TSC();

  SimulateTagRead = 0;
  SimulateTagWrite = 0;
  
  // print("NumberOnOff: " + tsc.DDCNumberOnOff);
  // print("DDCUseEvening: " + tsc.DDCUseEvening);
  // print("DDCUseHoliday: " + tsc.DDCUseHoliday);

  // WriteSomeSimulationValues();
  
  for (iDayIndex = 0; iDayIndex < (7 + 2); iDayIndex++) {

    // Mo-Fr 0..6, Evening -> Day 7, Holiday -> Day 8
    if ((iDayIndex == 7 && tsc.DDCUseEvening == 0) || (iDayIndex == 8 && tsc.DDCUseHoliday == 0)) {
      continue;
    }

    for (iStartStopIndex = 0; iStartStopIndex < tsc.DDCNumberOnOff; iStartStopIndex++) {

      sTagName = StartTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      sOn = TagReadInt(sTagName);
      
      if (sOn == undefined) {
        SetErrorDescription("Could not read timechannel tag '" + sTagName + "'");
        tsc.ClearDDCSchedule();
        return false;
      }

      sTagName = StopTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      sOff = TagReadInt(sTagName);
      
      if (sOff == undefined) {
        SetErrorDescription("Could not read timechannel tag '" + sTagName + "'");
        tsc.ClearDDCSchedule();
        return false;
      }

      // Do some fixups for PLC
      if (sOn == "2359" && sOff == "2359") {
        sOn = "0000";
        sOff = "2400";
      }
      if (sOff == "2359") {
        sOff = "2400";
      }

      tsc.SetDDCSchedule(iDayIndex, iStartStopIndex, 0, sOn);
      tsc.SetDDCSchedule(iDayIndex, iStartStopIndex, 1, sOff);
    }
  }

  return true;

}

function WriteDaysToDDC() {

  var iDayIndex;
  var iStartStopIndex;

  tsc = new TSC();

  SimulateTagRead = 0;
  SimulateTagWrite = 0;

  for (iDayIndex = 0; iDayIndex < (7 + 2); iDayIndex++) {

    // Mo-Fr 0..6, Evening -> Day 7, Holiday -> Day 8
    if ((iDayIndex == 7 && tsc.DDCUseEvening == 0) || (iDayIndex == 8 && tsc.DDCUseHoliday == 0)) {
        continue;
    }

    for (iStartStopIndex = 0; iStartStopIndex < tsc.DDCNumberOnOff; iStartStopIndex++) {

      sOn = tsc.GetDDCSchedule(iDayIndex, iStartStopIndex, 0);
      sOff = tsc.GetDDCSchedule(iDayIndex, iStartStopIndex, 1);

      // Do some fixups for PLC
      if (sOn == "0000" && sOff == "2400") {
        sOn = "2359";
        sOff = "2359";
      }
      if (sOff == "2400") {
        sOff = "2359";
      }

      sTagName = StartTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      if (TagWrite(sTagName, sOn) == false) {
        SetErrorDescription("Could not write timechannel tag '" + sTagName + "'");
        return false;
      }
      
      sTagName = StopTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      if (TagWrite(sTagName, sOff) == false) {
        SetErrorDescription("Could not write timechannel tag '" + sTagName + "'");
        return false;
      }            

    }
  }

  return true;
 
}

function ReadOnOffFix(on, off) {

  var result;

  if (off == "2359") {
    result = on + "2400";
  }
  else {
    result = on + off;
  }
  if (on == off && on == "2359") {
    result = "00002400";
  }

  return result;

}

function SaiaWriteOnOffFix(onoff) {

  var result;

  if (onoff.substring(4, 8) == "2400") {
    result = onoff.substring(0, 4) + "2359";
  }
  else {
    result = onoff;
  }

  if (onoff == "00002400") {
    result = "23592359";
  }

  return result;

}

function StartTagName(sTagNoPar, iDayIndex, iStartStopIndex) {

  var sTagName;
  var iIndex;
  var iTK;

  iIndex = iDayIndex + iStartStopIndex * (7 + 2) + 1;
  iTK = Math.floor(iIndex / 16);
  iIndex = iIndex - iTK * 16;
  iTK = iTK + 1;
 
  sTagName = tsc.TagNoPar + "" + iTK + ".F_" + iIndex;

  return sTagName;

}

function StopTagName(sTagNoPar, iDayIndex, iStartStopIndex) {

  var sTagName;
  var iIndex;
  var iTK;

  iIndex = iDayIndex + iStartStopIndex * (7 + 2) + 9 + 9 + 3 + 1;
  iTK = Math.floor(iIndex / 16);
  iIndex = iIndex - iTK * 16;
  iTK = iTK + 1;

  sTagName = tsc.TagNoPar + "" + iTK + ".F_" + iIndex;

  return sTagName;

}

//
// EDA/iFix seem to have problem using floats in database with SIM-driver, ex
//
// 2105 reads as 2105.01
// 2106 reads as 2105.98
//
function TagReadInt(sTagName) {

  var iValue = TagRead(sTagName);
  
  if (iValue == undefined) {
    return iValue;
  }

  // We need to cast iValue to Float (instead of string) first, add 0,5 and then make an int of it
  iValue = parseInt(parseFloat(iValue) + 0.5);
  
  // Do some sanity check
  if (iValue < 0) {
    iValue = 0;
  }
  if (iValue > 2400) {
    iValue = 2400;
  }
  
  return iValue;
  
}

function WriteSomeSimulationValues() {

  var iDayIndex;
  var iStartStopIndex;
  
  // We don't want these values to be written to PLC...
  SimulateTagWrite = 1;
  
  for (iDayIndex = 0; iDayIndex < (7 + 2); iDayIndex++) {

    // Mo-Fr 0..6, Evening -> Day 7, Holiday -> Day 8
    if ((iDayIndex == 7 && tsc.DDCUseEvening == 0) || (iDayIndex == 8 && tsc.DDCUseHoliday == 0)) {
        continue;
    }

    for (iStartStopIndex = 0; iStartStopIndex < tsc.DDCNumberOnOff; iStartStopIndex++) {

      sTagName = StartTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      // print("sTagName Start (iDayIndex: " + iDayIndex + ") (iStartStopIndex: " + iStartStopIndex + "): " + sTagName);
      TagWrite(sTagName, iStartStopIndex * 1100 + iDayIndex);

      sTagName = StopTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      // print("sTagName Stop (iDayIndex: " + iDayIndex + ") (iStartStopIndex: " + iStartStopIndex + "): " + sTagName);
      TagWrite(sTagName, 1000 + iStartStopIndex * 1100 + iDayIndex);

    }
  }
}