﻿////////////////////////////////////////////////////////
//
// $DDCDriver.Name: FOS_SAIA_Version_1
// $DDCDriver.Desc: FÖS SAIA rullande över dygnet - version 1
// 
// Denna driver är för FÖS SAIA där man angett tider som rullar över dygnet, ex onsdag 1600..0200 vilket betyder onsdag 1600..2400
// samt torsdag 0000..0200
//
// Dokumentet är sparat i UTF-8 för att vara compliant med JavaScript (i annat fall orsakar svenska tecken ett parsingfel)
// 
// --------------------------------------------------------------------------------------------------------------------------------
// Date     / Vers   / Sign / Comment
// --------------------------------------------------------------------------------------------------------------------------------
// 16.12.06 / 01.00  /  TR  / Main
//
//
////////////////////////////////////////////////////////

function ReadDaysFromDDC() {

  var iDayIndex;
  var iStartStopIndex;
  var sTagName;

  var iDayCounter; 

  var iStartTime = [];
  var iStopTime = [];
  var iStopTimeFromPreviousDay = [];
  var iExtraStartStopToAdd;
  
  var sOn;
  var sOff;
  
  var iOn;
  var iOff;

  var iNumberOfDeviceStartStop;

  tsc = new TSC();
  
  SimulateTagRead = 1;
  SimulateTagWrite = 1;
  
  if (tsc.DDCNumberOnOff != 3)
  {
    SetErrorDescription("Number of start/stop must be 3 for FlexTime even if device supports only 2");
    tsc.ClearDDCSchedule();
    return false;
  }

  iNumberOfDeviceStartStop = 2;
  
  // print("NumberOnOff: " + tsc.DDCNumberOnOff);
  // print("DDCUseEvening: " + tsc.DDCUseEvening);
  // print("DDCUseHoliday: " + tsc.DDCUseHoliday);

  //CreateSomeSimulationValues();

  //
  // First of all -> read all timestamps into an array
  //  

  //
  // We run only Mo..Su, because it is impossible to know what day yesterday was if this is a specialday
  //
  // Mo-Su 0..6
  //
  //
  for (iDayIndex = 0; iDayIndex < 7; iDayIndex++) {

    iStopTimeFromPreviousDay[iDayIndex] = 0;

    for (iStartStopIndex = 0; iStartStopIndex < iNumberOfDeviceStartStop; iStartStopIndex++) {

      sTagName = StartTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      sOn = TagReadInt(sTagName);
      
      if (sOn == undefined) {
        SetErrorDescription("Could not read timechannel tag '" + sTagName + "'");
        tsc.ClearDDCSchedule();
        return false;
      }

      sTagName = StopTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      sOff = TagReadInt(sTagName);
      
      if (sOff == undefined) {
        SetErrorDescription("Could not read timechannel tag '" + sTagName + "'");
        tsc.ClearDDCSchedule();
        return false;
      }

      // Do some fixups for PLC
      // Run all day (not used if both are "0000", but run all day if they are equal using some other value, ex "2359")
      if (sOn == sOff && sOn != "0000") {
        sOn = "0000";
        sOff = "2400";
      }
      if (sOff == "2359") {
        sOff = "2400";
      }

      iStartTime[iDayIndex * 7 + iStartStopIndex] = parseInt(sOn);
      iStopTime[iDayIndex * 7 + iStartStopIndex] = parseInt(sOff);

      print("iDayIndex: " + iDayIndex + ", iStartStopIndex: " + iStartStopIndex + " -> "  + sOn + ".." + sOff);
      
    }
  }

  //
  // Calc time strings to FlexTime
  //

  // Run 8 loops to recalc monday if it runs overnight sunday-> monday
  for (iDayIndex = 0, iDayCounter = 0; iDayCounter < 8; iDayIndex++, iDayCounter++) {
    
    // Only 0..6
    if (iDayIndex > 6)
    {
      iDayIndex = 0;
    }
    
    if (iDayIndex == 0)      
    {
      iPreviousDay = 6;
    }
    else
    {
      iPreviousDay = iDayIndex - 1;
    }
      
    if (iDayIndex >= 6)      
    {
      iNextDay = 0;
    }
    else
    {
      iNextDay = iDayIndex + 1;
    }
     
    // Set first start stop to ex 0000..0200, add one extra column
    if (iStopTimeFromPreviousDay[iDayIndex] > 0)
    {
      tsc.SetDDCSchedule(iDayIndex, 0, 0, 0);
      tsc.SetDDCSchedule(iDayIndex, 0, 1, iStopTimeFromPreviousDay[iDayIndex]);
      iExtraStartStopToAdd = 1;
    }
    else
    {
      iExtraStartStopToAdd = 0;
    }

    for (iStartStopIndex = 0; (iStartStopIndex + iExtraStartStopToAdd) < tsc.DDCNumberOnOff; iStartStopIndex++) {
      // Find out if this day continues from the day before, ex stoptime == 0200 and starttime previous day is 1200
      
      iOn = iStartTime[iDayIndex * 7 + iStartStopIndex];
      iOff = iStopTime[iDayIndex * 7 + iStartStopIndex];
      
      if (iOff > iOn)
      {
        // Normal start/stop
        tsc.SetDDCSchedule(iDayIndex, iStartStopIndex + iExtraStartStopToAdd, 0, iOn);
        tsc.SetDDCSchedule(iDayIndex, iStartStopIndex + iExtraStartStopToAdd, 1, iOff);
      }
      else
      {
        if (iOff < iOn)
        {
          // Continue to run next day      
          tsc.SetDDCSchedule(iDayIndex, iStartStopIndex + iExtraStartStopToAdd, 0, iOn);
          tsc.SetDDCSchedule(iDayIndex, iStartStopIndex + iExtraStartStopToAdd, 1, 2400);
          iStopTimeFromPreviousDay[iNextDay] = iOff;
        }
      }
    }
  }
  
  // Special days may not run overnight, we don't know what day it was before this night or what's coming next day
  for (iDayIndex = 7; iDayIndex < (7 + 2); iDayIndex++) {

    // Mo-Fr 0..6, Evening -> Day 7, Holiday -> Day 8
    if ((iDayIndex == 7 && tsc.DDCUseEvening == 0) || (iDayIndex == 8 && tsc.DDCUseHoliday == 0)) {
        continue;
    }

    for (iStartStopIndex = 0; iStartStopIndex < iNumberOfDeviceStartStop; iStartStopIndex++) {

      sTagName = StartTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      sOn = TagReadInt(sTagName);
      
      if (sOn == undefined) {
        SetErrorDescription("Could not read timechannel tag '" + sTagName + "'");
        tsc.ClearDDCSchedule();
        return false;
      }

      sTagName = StopTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      sOff = TagReadInt(sTagName);
      
      if (sOff == undefined) {
        SetErrorDescription("Could not read timechannel tag '" + sTagName + "'");
        tsc.ClearDDCSchedule();
        return false;
      }

      // Do some fixups for PLC
      if (sOn == "2359" && sOff == "2359") {
        sOn = "0000";
        sOff = "2400";
      }
      if (sOff == "2359") {
        sOff = "2400";
      }

      tsc.SetDDCSchedule(iDayIndex, iStartStopIndex, 0, sOn);
      tsc.SetDDCSchedule(iDayIndex, iStartStopIndex, 1, sOff);
    }
  }

  for (iDayIndex = 0, iDayCounter = 0; iDayIndex < 7 + 2; iDayIndex++) {
    print("iDayIndex " + iDayIndex + " -> " + tsc.GetDDCSchedule(iDayIndex));
  }

  return true;
  
}

function WriteDaysToDDC() {

  var iDayIndex;
  var iStartStopIndex;
  var iIndex;
  var sTagName;

  var iDayCounter;

  var iStartTime = [];
  var iStopTime = [];
  var iStopTimeFromPreviousDay = [];
  var iExtraStartStopToAdd;

  var sOn;
  var sOff;

  var iOn;
  var iOff;

  var iNumberOfDeviceStartStop;
  var iTagStartStopIndex;

  var iIgnoreThisStartStop;

  tsc = new TSC();

  SimulateTagRead = 1;
  SimulateTagWrite = 1;

//CreateSomeSimulationValues();
//ReadDaysFromDDC();

  if (tsc.DDCNumberOnOff != 3)
  {
    SetErrorDescription("Number of start/stop must be 3 for FlexTime even if device supports only 2");
    tsc.ClearDDCSchedule();
    return false;
  }

  iNumberOfDeviceStartStop = 2;

  // print("NumberOnOff: " + tsc.DDCNumberOnOff);
  // print("DDCUseEvening: " + tsc.DDCUseEvening);
  // print("DDCUseHoliday: " + tsc.DDCUseHoliday);

  // Do some init stuff
  for (iDayIndex = 0, iDayCounter = 0; iDayIndex < 7 + 2; iDayIndex++) {

    for (iStartStopIndex = 0, iTagStartStopIndex = 0; iStartStopIndex < iNumberOfDeviceStartStop; iStartStopIndex++) {

      // Prepare as it might run around using
      iStartTime[iDayIndex * 7 + iTagStartStopIndex] = 0;
      iStopTime[iDayIndex * 7 + iTagStartStopIndex] = 0;

    }
  
    print("iDayIndex " + iDayIndex + " -> " + tsc.GetDDCSchedule(iDayIndex));
  }

  //
  // We run only Mo..Su, because it is impossible to know what day yesterday was if this is a specialday
  //
  // Mo-Su 0..6
  //
  //

  //
  // Calc time strings from FlexTime
  //

  // Run 7 loops
  for (iDayIndex = 0, iDayCounter = 0; iDayIndex < 7; iDayIndex++) {

    if (iDayIndex == 0) {
      iPreviousDay = 6;
    }
    else {
      iPreviousDay = iDayIndex - 1;
    }

    if (iDayIndex >= 6) {
      iNextDay = 0;
    }
    else
    {
      iNextDay = iDayIndex + 1;
    }

    for (iStartStopIndex = 0, iTagStartStopIndex = 0; iStartStopIndex < tsc.DDCNumberOnOff; iStartStopIndex++) {
      // Find out if this day continues from the day before, ex stoptime == 0200 and starttime previous day is 1200

      iOn = tsc.GetDDCSchedule(iDayIndex, iStartStopIndex, 0);
      iOff = tsc.GetDDCSchedule(iDayIndex, iStartStopIndex, 1);

      iIgnoreThisStartStop = false;
      
      // Possible run-over-midnight from yesterday
      if (iStartStopIndex == 0 && iOn == 0 && iOff > 0 && iOff < 2400)
      {
        // Find last time period previous day, if it is 2400 then we have run over-midnight
        for (iIndex = tsc.DDCNumberOnOff - 1; iIndex >= 0; iIndex--)
        {
          print("Scanning " + tsc.GetDDCSchedule(iPreviousDay, iIndex, 1));

          if (tsc.GetDDCSchedule(iPreviousDay, iIndex, 1) == "2400") {
           // print("hej:" + iDayIndex + "/" + iTagStartStopIndex);
            // Ignore the first start/stop, because then previous day would have already set correct periods (or will if it is a sunday)
            iIgnoreThisStartStop = true;
            break;
          }
        }
      }

      if (iIgnoreThisStartStop)
      {
        //print("hejhej:" + iDayIndex + "/" + iTagStartStopIndex);
        continue;
      }
       
      // Possible run-over-midnight 'til tomorrow
      if (iOn > 0 && iOn < 2400 && iOff == 2400) {
        //print("hej2:" + iDayIndex + "/" + iTagStartStopIndex);
      
        // If next day first period starts at midnight and has some stop time then it is a run-over-midnight thing
        if (tsc.GetDDCSchedule(iNextDay, 0, 0) == "0000" && tsc.GetDDCSchedule(iNextDay, 0, 1) != "0000") {
          //print("hej3:" + iDayIndex + "/" + iTagStartStopIndex);

          iOff = parseInt(tsc.GetDDCSchedule(iNextDay, 0, 1));

        }
        
      }
      
      if (iOn == 0 && iOff == 2400)
      {
        iOn = 2359;
        iOff = 2359;
      }
      if (iOff == 2400)
      {
        iOff = 2359;
      }

      if (iTagStartStopIndex < iNumberOfDeviceStartStop)
      {
        iStartTime[iDayIndex * 7 + iTagStartStopIndex] = iOn;
        iStopTime[iDayIndex * 7 + iTagStartStopIndex] = iOff;
      }

      iTagStartStopIndex++;
      
    }
  }

  //
  // Finally write to tags
  //

  for (iDayIndex = 0; iDayIndex < 7; iDayIndex++) {

    for (iStartStopIndex = 0; iStartStopIndex < iNumberOfDeviceStartStop; iStartStopIndex++) {

      sOn = iStartTime[iDayIndex * 7 + iStartStopIndex];
      sOff = iStopTime[iDayIndex * 7 + iStartStopIndex];

      print("iDayIndex: " + iDayIndex + ", iStartStopIndex: " + iStartStopIndex + " -> " + sOn + ".." + sOff);

      sTagName = StartTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      if (TagWrite(sTagName, sOn) == false) {
        SetErrorDescription("Could not write timechannel tag '" + sTagName + "'");
        return false;
      }

      sTagName = StopTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      if (TagWrite(sTagName, sOff) == false) {
        SetErrorDescription("Could not write timechannel tag '" + sTagName + "'");
        return false;
      }

    }
  }    

  // Special days may not run overnight, we don't know what day it was before this night or what's coming next day
  for (iDayIndex = 7; iDayIndex < (7 + 2); iDayIndex++) {

    // Mo-Fr 0..6, Evening -> Day 7, Holiday -> Day 8
    if ((iDayIndex == 7 && tsc.DDCUseEvening == 0) || (iDayIndex == 8 && tsc.DDCUseHoliday == 0)) {
      continue;
    }

    for (iStartStopIndex = 0; iStartStopIndex < iNumberOfDeviceStartStop; iStartStopIndex++) {

      sOn = tsc.GetDDCSchedule(iDayIndex, iStartStopIndex, 0);
      sOff = tsc.GetDDCSchedule(iDayIndex, iStartStopIndex, 1);

      // Do some fixups for PLC
      if (sOn == "0000" && sOff == "2400") {
        sOn = "2359";
        sOff = "2359";
      }
      if (sOff == "2400") {
        sOff = "2359";
      }

      sTagName = StartTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      if (TagWrite(sTagName, sOn) == false) {
        SetErrorDescription("Could not write timechannel tag '" + sTagName + "'");
        return false;
      }

      sTagName = StopTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      if (TagWrite(sTagName, sOff) == false) {
        SetErrorDescription("Could not write timechannel tag '" + sTagName + "'");
        return false;
      }            
      
    }
    
  }

  for (iDayIndex = 0; iDayIndex < 7; iDayIndex++) {

    for (iStartStopIndex = 0; iStartStopIndex < iNumberOfDeviceStartStop; iStartStopIndex++) {

      sOn = iStartTime[iDayIndex * 7 + iStartStopIndex];
      sOff = iStopTime[iDayIndex * 7 + iStartStopIndex];

      print("iDayIndex: " + iDayIndex + ", iStartStopIndex: " + iStartStopIndex + " -> " + sOn + ".." + sOff);

    }
  }   
  
  return true;
 
}

function StartTagName(sTagNoPar, iDayIndex, iStartStopIndex) {

  var sTagName;
  var iIndex;
  var iTK;

  iIndex = iDayIndex + iStartStopIndex * (7 + 2) + 1;
  iTK = Math.floor(iIndex / 16);
  iIndex = iIndex - iTK * 16;
  iTK = iTK + 1;
 
  sTagName = tsc.TagNoPar + "" + iTK + ".F_" + iIndex;

  return sTagName;

}

function StopTagName(sTagNoPar, iDayIndex, iStartStopIndex) {

  var sTagName;
  var iIndex;
  var iTK;

  iIndex = iDayIndex + iStartStopIndex * (7 + 2) + 9 + 9 + 3 + 1;
  iTK = Math.floor(iIndex / 16);
  iIndex = iIndex - iTK * 16;
  iTK = iTK + 1;

  sTagName = tsc.TagNoPar + "" + iTK + ".F_" + iIndex;

  return sTagName;

}

//
// EDA/iFix seem to have problem using floats in database with SIM-driver, ex
//
// 2105 reads as 2105.01
// 2106 reads as 2105.98
//
function TagReadInt(sTagName) {

  var iValue = TagRead(sTagName);
  
  if (iValue == undefined) {
    return iValue;
  }

  // We need to cast iValue to Float (instead of string) first, add 0,5 and then make an int of it
  iValue = parseInt(parseFloat(iValue) + 0.5);
  
  // Do some sanity check
  if (iValue < 0) {
    iValue = 0;
  }
  if (iValue > 2400) {
    iValue = 2400;
  }
  
  return iValue;
  
}

function CreateSomeSimulationValues() {

  var iDayIndex;
  var iStartStopIndex;
  
  // We don't want these values to be written to PLC...
  SimulateTagWrite = 1;

  var iNumberOfDeviceStartStop;

  iNumberOfDeviceStartStop = 2;
  
  // Clear tag list
  TagWrite("*");

  for (iDayIndex = 0; iDayIndex < (7 + 2); iDayIndex++) {

    // Mo-Fr 0..6, Evening -> Day 7, Holiday -> Day 8
    if ((iDayIndex == 7 && tsc.DDCUseEvening == 0) || (iDayIndex == 8 && tsc.DDCUseHoliday == 0)) {
        continue;
    }

    for (iStartStopIndex = 0; iStartStopIndex < iNumberOfDeviceStartStop; iStartStopIndex++) {

      sTagName = StartTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      // print("sTagName Start (iDayIndex: " + iDayIndex + ") (iStartStopIndex: " + iStartStopIndex + "): " + sTagName);
      TagWrite(sTagName, 0);

      sTagName = StopTagName(tsc.TagNoPar, iDayIndex, iStartStopIndex);
      // print("sTagName Stop (iDayIndex: " + iDayIndex + ") (iStartStopIndex: " + iStartStopIndex + "): " + sTagName);
      TagWrite(sTagName, 0);

    }
  }


  TagWrite(StartTagName(tsc.TagNoPar, 0, 0), 1500);
  TagWrite(StopTagName(tsc.TagNoPar, 0, 0), 1700);
  TagWrite(StartTagName(tsc.TagNoPar, 0, 1), 1800);
  TagWrite(StopTagName(tsc.TagNoPar, 0, 1), 200);

  TagWrite(StartTagName(tsc.TagNoPar, 6, 0), 1600);
  TagWrite(StopTagName(tsc.TagNoPar, 6, 0), 1800);
  TagWrite(StartTagName(tsc.TagNoPar, 6, 1), 1900);
  TagWrite(StopTagName(tsc.TagNoPar, 6, 1), 200);  
    

}

/*

Spec OSG Mall IO-lista 20160929.xlsx

Tidkanal: Arrayer =>		
Tag namn i SUL		
A_TAG	A_IOAD	A_DESC
XXXX-LB01-TK01	R[16]	[RW]@;;;;LB01-TKD;SCADA array block 1;
XXXX-LB01-TK02	R[16]	[RW]@;;;;LB01-TKD;SCADA array block 2;
XXXX-LB01-TK03	R[16]	[RW]@;;;;LB01-TKD;SCADA array block 3; 
		
TAGar spec i PLC => 		
XXXX-LB01-TK-MAN	XXXX-LB01-TK01+0	[RW][HMI]@1;3;;;LB01-TK;1=AUTO, 2=HT, 3=HF;
XXXX-LB01-TK-STAT1	XXXX-LB01-TK01+1	[RW][HMI]@0;2359;;;LB01-TKD1;Tillslag Mån;
XXXX-LB01-TK-STAT2	XXXX-LB01-TK01+2	[RW][HMI]@0;2359;;;LB01-TKD1;Tillslag Tis;
XXXX-LB01-TK-STAT3	XXXX-LB01-TK01+3	[RW][HMI]@0;2359;;;LB01-TKD1;Tillslag Ons;
XXXX-LB01-TK-STAT4	XXXX-LB01-TK01+4	[RW][HMI]@0;2359;;;LB01-TKD1;Tillslag Tor;
XXXX-LB01-TK-STAT5	XXXX-LB01-TK01+5	[RW][HMI]@0;2359;;;LB01-TKD1;Tillslag Fre;
XXXX-LB01-TK-STAT6	XXXX-LB01-TK01+6	[RW][HMI]@0;2359;;;LB01-TKD1;Tillslag Lör;
XXXX-LB01-TK-STAT7	XXXX-LB01-TK01+7	[RW][HMI]@0;2359;;;LB01-TKD1;Tillslag Sön;
XXXX-LB01-TK-STAT8	XXXX-LB01-TK01+8	[RW][HMI]@0;2359;;;LB01-TKD1;Tillslag HDA;
XXXX-LB01-TK-STAT9	XXXX-LB01-TK01+9	[RW][HMI]@0;2359;;;LB01-TKD1;Tillslag HD;
XXXX-LB01-TK-STAT10	XXXX-LB01-TK01+10	[RW][HMI]@0;2359;;;LB01-TKD2;Tillslag Mån;
XXXX-LB01-TK-STAT11	XXXX-LB01-TK01+11	[RW][HMI]@0;2359;;;LB01-TKD2;Tillslag Tis;
XXXX-LB01-TK-STAT12	XXXX-LB01-TK01+12	[RW][HMI]@0;2359;;;LB01-TKD2;Tillslag Ons;
XXXX-LB01-TK-STAT13	XXXX-LB01-TK01+13	[RW][HMI]@0;2359;;;LB01-TKD2;Tillslag Tor;
XXXX-LB01-TK-STAT14	XXXX-LB01-TK01+14	[RW][HMI]@0;2359;;;LB01-TKD2;Tillslag Fre;
XXXX-LB01-TK-STAT15	XXXX-LB01-TK01+15	[RW][HMI]@0;2359;;;LB01-TKD2;Tillslag Lör;
XXXX-LB01-TK-STAT16	XXXX-LB01-TK02+0	[RW][HMI]@0;2359;;;LB01-TKD2;Tillslag Sön;
XXXX-LB01-TK-STAT17	XXXX-LB01-TK02+1	[RW][HMI]@0;2359;;;LB01-TKD2;Tillslag HDA;
XXXX-LB01-TK-STAT18	XXXX-LB01-TK02+2	[RW][HMI]@0;2359;;;LB01-TKD2;Tillslag HD;
XXXX-LB01-TK-STAT19	XXXX-LB01-TK02+3	[RW][HMI]@0;2359;;;LB01-TK-SD1;Tillslag;
XXXX-LB01-TK-STAT20	XXXX-LB01-TK02+4	[RW][HMI]@0;2359;;;LB01-TK-SD2;Tillslag;
XXXX-LB01-TK-STAT21	XXXX-LB01-TK02+5	[RW][HMI]@0;2359;;;LB01-TK-SD3;Tillslag;
XXXX-LB01-TK-STOT1	XXXX-LB01-TK02+6	[RW][HMI]@0;2359;;;LB01-TKD1;Frånslag Mån;
XXXX-LB01-TK-STOT2	XXXX-LB01-TK02+7	[RW][HMI]@0;2359;;;LB01-TKD1;Frånslag Tis;
XXXX-LB01-TK-STOT3	XXXX-LB01-TK02+8	[RW][HMI]@0;2359;;;LB01-TKD1;Frånslag Ons;
XXXX-LB01-TK-STOT4	XXXX-LB01-TK02+9	[RW][HMI]@0;2359;;;LB01-TKD1;Frånslag Tor;
XXXX-LB01-TK-STOT5	XXXX-LB01-TK02+10	[RW][HMI]@0;2359;;;LB01-TKD1;Frånslag Fre;
XXXX-LB01-TK-STOT6	XXXX-LB01-TK02+11	[RW][HMI]@0;2359;;;LB01-TKD1;Frånslag Lör;
XXXX-LB01-TK-STOT7	XXXX-LB01-TK02+12	[RW][HMI]@0;2359;;;LB01-TKD1;Frånslag Sön;
XXXX-LB01-TK-STOT8	XXXX-LB01-TK02+13	[RW][HMI]@0;2359;;;LB01-TKD1;Frånslag HDA;
XXXX-LB01-TK-STOT9	XXXX-LB01-TK02+14	[RW][HMI]@0;2359;;;LB01-TKD1;Frånslag HD;
XXXX-LB01-TK-STOT10	XXXX-LB01-TK02+15	[RW][HMI]@0;2359;;;LB01-TKD2;Frånslag Mån;
XXXX-LB01-TK-STOT11	XXXX-LB01-TK03+0	[RW][HMI]@0;2359;;;LB01-TKD2;Frånslag Tis;
XXXX-LB01-TK-STOT12	XXXX-LB01-TK03+1	[RW][HMI]@0;2359;;;LB01-TKD2;Frånslag Ons;
XXXX-LB01-TK-STOT13	XXXX-LB01-TK03+2	[RW][HMI]@0;2359;;;LB01-TKD2;Frånslag Tor;
XXXX-LB01-TK-STOT14	XXXX-LB01-TK03+3	[RW][HMI]@0;2359;;;LB01-TKD2;Frånslag Fre;
XXXX-LB01-TK-STOT15	XXXX-LB01-TK03+4	[RW][HMI]@0;2359;;;LB01-TKD2;Frånslag Lör;
XXXX-LB01-TK-STOT16	XXXX-LB01-TK03+5	[RW][HMI]@0;2359;;;LB01-TKD2;Frånslag Sön;
XXXX-LB01-TK-STOT17	XXXX-LB01-TK03+6	[RW][HMI]@0;2359;;;LB01-TKD2;Frånslag HDA;
XXXX-LB01-TK-STOT18	XXXX-LB01-TK03+7	[RW][HMI]@0;2359;;;LB01-TKD2;Frånslag HD;
XXXX-LB01-TK-STOT19	XXXX-LB01-TK03+8	[RW][HMI]@0;2359;;;LB01-TK-SD1;Frånslag ;
XXXX-LB01-TK-STOT20	XXXX-LB01-TK03+9	[RW][HMI]@0;2359;;;LB01-TK-SD2;Frånslag;
XXXX-LB01-TK-STOT21	XXXX-LB01-TK03+10	[RW][HMI]@0;2359;;;LB01-TK-SD3;Frånslag;
XXXX-LB01-TK-STAD1	XXXX-LB01-TK03+11	[RW][HMI]@0;1231;;;LB01-TK-SD1;Datum;
XXXX-LB01-TK-STAD2	XXXX-LB01-TK03+12	[RW][HMI]@0;1231;;;LB01-TK-SD2;Datum ;
XXXX-LB01-TK-STAD3	XXXX-LB01-TK03+13	[RW][HMI]@0;1231;;;LB01-TK-SD3;Datum ;
XXXX-LB01-TK-STAD4	XXXX-LB01-TK03+14	[RW][HMI]@0;1231;;;LB01-TK-SP1;Start datum ;
XXXX-LB01-TK-STOD1	XXXX-LB01-TK03+15	[RW][HMI]@0;1231;;;LB01-TK-SP1;Stopp datum ;

*/